==> limitorderv2-sdk-0.1.36.tgz: package/src/fillorder.ts <==

import { validateAndParseAddress } from "./utils";
import { LimitOrder } from "./order";
import { utils, Contract, BigNumber, ethers } from 'ethers'
import { getVerifyingContract } from './constants'
import { abi } from './entities/limitOrderContractABI'

export class FillLimitOrder {
    public readonly order: LimitOrder;
    public readonly path: string[];
    public readonly minimumAmoutOutExternal: BigNumber;
    public readonly amountToFill: BigNumber;
    public readonly limitOrderReceiver: string;
    public readonly to: string;
    public readonly tokenIn: string;
    public readonly tokenOut: string;
    public readonly limitOrderReceiverData: string;


    constructor(order: LimitOrder, path: string[], minimumAmoutOutExternal: BigNumber, amountToFill: BigNumber, limitOrderReceiver: string, to: string) {
        this.order = order;

        this.path = path.map(validateAndParseAddress);

        this.minimumAmoutOutExternal = minimumAmoutOutExternal;
        this.amountToFill = amountToFill;
        this.limitOrderReceiver = validateAndParseAddress(limitOrderReceiver);
        this.to = validateAndParseAddress(to);
        this.tokenIn = order.amountIn.token.address;
        this.tokenOut = order.amountOut.token.address;

        this.limitOrderReceiverData = utils.defaultAbiCoder.encode(
            ["address[]", "uint256", "address"],
            [this.path, this.minimumAmoutOutExternal.toString(), this.to]
        )
    }

    public fillOrderOpen(signer: ethers.Signer, { forceExecution = false, gasPrice }: { forceExecution: boolean, gasPrice: BigNumber }) {
        return this.fillOrder(signer, { forceExecution, gasPrice, open: true });
    }

    public async fillOrder(signer: ethers.Signer, { forceExecution = false, gasPrice, open = false }: { forceExecution: boolean, gasPrice: BigNumber, open: boolean })
        : Promise<{ executed: boolean, transactionHash: string }> {

        const func = open ? 'fillOrderOpen' : 'fillOrder';

        const orderArg = [
            this.order.maker,
            this.order.amountInRaw,
            this.order.amountOutRaw,
            this.order.recipient,
            this.order.startTime,
            this.order.endTime,
            this.order.stopPrice,
            this.order.oracleAddress,
            this.order.oracleData,
            this.amountToFill.toString(),
            this.order.v,
            this.order.r,
            this.order.s
        ];

        const limitOrderContract = new Contract(getVerifyingContract(this.order.chainId), abi, signer);

        let gasLimit;
        let executed = true;

        try {
            gasLimit = await limitOrderContract.estimateGas[func](orderArg,
                this.path[0],
                this.path[this.path.length - 1],
                this.limitOrderReceiver,
                this.limitOrderReceiverData
            );
        } catch (e) {
            if (forceExecution) {
                console.log('Failed to estimate gas');
                gasLimit = "1000000";
                executed = true;
            } else {
                return { executed: false, transactionHash: "0x0" };
            }
        }

        const fillOrderTx = await limitOrderContract[func](
            orderArg,
            this.path[0],
            this.path[this.path.length - 1],
            this.limitOrderReceiver,
            this.limitOrderReceiverData, { gasLimit, gasPrice }
        );

        return { executed, transactionHash: fillOrderTx.hash };
    }
}

==> limitorderv2-sdk-0.1.45.tgz: package/src/fillorder.ts <==

import { validateAndParseAddress } from "./utils";
import { LimitOrder } from "./order";
import { utils, Contract, BigNumber, ethers } from 'ethers'
import { getVerifyingContract } from './constants'
import { abi } from './entities/limitOrderContractABI'

export class FillLimitOrder {
    public readonly order: LimitOrder;
    public readonly path: string[];
    public readonly amountExternal: BigNumber;
    public readonly amountToFill: BigNumber;
    public readonly limitOrderReceiver: string;
    public readonly to: string;
    public readonly tokenIn: string;
    public readonly tokenOut: string;
    public readonly limitOrderReceiverData: string;


    constructor(order: LimitOrder, path: string[], amountExternal: BigNumber, amountToFill: BigNumber, limitOrderReceiver: string, to: string, keepTokenIn = false) {

        this.order = order;
        this.path = path.map(validateAndParseAddress);
        this.amountExternal = amountExternal;
        this.amountToFill = amountToFill;
        this.limitOrderReceiver = validateAndParseAddress(limitOrderReceiver);
        this.to = validateAndParseAddress(to);
        this.tokenIn = order.amountIn.token.address;
        this.tokenOut = order.amountOut.token.address;

        this.limitOrderReceiverData = utils.defaultAbiCoder.encode(
            ["address[]", "uint256", "address", "bool"],
            [this.path, this.amountExternal.toString(), this.to, keepTokenIn]
        );
    }

    public fillOrderOpen(signer: ethers.Signer, extra: { forceExecution?: boolean, gasPrice?: BigNumber, nonce?: number, open?: boolean }) {
        extra.open = true;
        return this.fillOrder(signer, extra);
    }

    public async fillOrder(signer: ethers.Signer, extra: { forceExecution?: boolean, gasPrice?: BigNumber, open?: boolean, nonce?: number })
        : Promise<{ executed: boolean, transactionHash: string }> {

        const { gasPrice, nonce, forceExecution = false, open = false } = extra;

        const func = open ? 'fillOrderOpen' : 'fillOrder';

        const orderArg = [
            this.order.maker,
            this.order.amountInRaw,
            this.order.amountOutRaw,
            this.order.recipient,
            this.order.startTime,
            this.order.endTime,
            this.order.stopPrice,
            this.order.oracleAddress,
            this.order.oracleData,
            this.amountToFill.toString(),
            this.order.v,
            this.order.r,
            this.order.s
        ];

        const limitOrderContract = new Contract(getVerifyingContract(this.order.chainId), abi, signer);

        let gasLimit;
        let executed = true;

        try {
            gasLimit = await limitOrderContract.estimateGas[func](orderArg,
                this.path[0],
                this.path[this.path.length - 1],
                this.limitOrderReceiver,
                this.limitOrderReceiverData
            );
        } catch (e) {

            if (forceExecution) {
                console.log('Failed to estimate gas, forcing execution');
                gasLimit = "400000"; // 400k
                executed = true;
            } else {
                return { executed: false, transactionHash: "0x0" };
            }

        }

        const fillOrderTx = await limitOrderContract[func](
            orderArg,
            this.path[0],
            this.path[this.path.length - 1],
            this.limitOrderReceiver,
            this.limitOrderReceiverData, { gasLimit, gasPrice, nonce }
        );

        return { executed, transactionHash: fillOrderTx.hash };
    }
}
